@@ -75,8 +75,7 @@ def selenium_find(link: str) -> list:
                     list_of_dict_values = list(obj.values())
                     for value in list_of_dict_values:
                         if str(value).find("m3u8") > -1 and str(value) not in res:
-                            reqstatus = r.get(value, allow_redirects=True).status_code
-                            if reqstatus == 200:
+                            if int(r.get(value, allow_redirects=True).status_code) == 200:
                                 pind2(f"Found a stream - {str(value)}", colours.OKGREEN, otype.REGULAR)
                             res.append(value)
             except KeyboardInterrupt:
@@ -105,8 +104,9 @@ def html_find(link: str) -> list:
         for match in re.findall(r"([\'][^\'\"]+(\.m3u8)[^\'\"]*[\'])|([\"][^\'\"]+(\.m3u8)[^\'\"]*[\"])", content):
             for i in match:
                 if (i.count("\'") == 2 and i.count("\"") == 0) or (i.count("\"") == 2 and i.count("\'") == 0) and ".m3u8" in i and i[1:-1] not in res:
-                    res.append(i[1:-1])
-                    pind2(f"Found a stream - {str(i[1:-1])}", colours.OKGREEN, otype.REGULAR)
+                    if int(r.get(i[1:-1], allow_redirects=True).status_code) == 200:
+                        res.append(i[1:-1])
+                        pind2(f"Found a stream - {str(i[1:-1])}", colours.OKGREEN, otype.REGULAR)
     except Exception as e:
         pass
     return res
@@ -178,6 +178,10 @@ def make_match(api_res, hosts, lg) -> list:
     for g in api_res:
         ht = g['homeTeam']
         at = g['awayTeam']
+        if lg == EF:
+            host_id = str(g['eventLink'].split('/')[-1]).split("?")[0]
+        else:
+            host_id = str(g['eventLink']).split('/')[-1]
         match = {
             "home_team": {
                 "name": ht['name'],
@@ -190,7 +194,7 @@ def make_match(api_res, hosts, lg) -> list:
             "match": {
                 "name": g.get('name', ''),
                 "img_location": "",
-                "url": f"{hosts[0]}{str(g['eventLink']).split('/')[-1]}{hosts[1]}"
+                "url": f"{hosts[0]}{host_id}{hosts[1]}"
             }
         }
         if match['match']['name'] == '':
@@ -207,11 +211,12 @@ def find_streams(lg: str) -> list:
     """
     Finds current games that are active for a given league.
     """
+    STREAM_LINK = os.environ.get('stream_link')
     p(f"COLLECTING {lg.upper()} STREAMING LINKS", colours.HEADER, otype.REGULAR)
     res = []
     games = []
     date = datetime.datetime.today().strftime('%Y-%m-%d')
-    hosts = ["https://sportscentral.io/streams-table/"]
+    hosts = [f"{STREAM_LINK}/streams-table/"]
     path = None
     if lg == NHL:
         path = "nhl-tournaments"
@@ -224,13 +229,13 @@ def find_streams(lg: str) -> list:
         hosts.append("/basketball?new-ui=1&origin=reddit.rnbastreams.com")
     elif lg == EF:
         hosts.append("/soccer?new-ui=1&origin=redi1.soccerstreams.net")
-        api_res = json.loads(r.get(f"https://sportscentral.io/new-api/matches?timeZone=300&date={date}").content)
+        api_res = json.loads(r.get(f"{STREAM_LINK}/new-api/matches?timeZone=300&date={date}").content)
         for i in api_res:
             if i['country']['name'] == "England":
                 games.extend(make_match(i['events'], hosts, lg))
 
     if path:
-        main_link = f"https://sportscentral.io/api/{path}?date={date}"
+        main_link = f"{STREAM_LINK}/api/{path}?date={date}"
         api_res = json.loads(r.request("GET", main_link).content)[0]['events']
         games = make_match(api_res, hosts, lg)
 
